# Accounts

Accounts can refer to both physical and virtual accounts, such as your mutual fund folios, demat accounts etc.

::: mkdocs-click
    :module: niveshpy.cli.account
    :command: cli
    :prog_name: niveshpy accounts
    :depth: 1
    :list_subcommands: true

## Model Reference

::: niveshpy.models.account
